﻿using Syncfusion.Drawing;
using Syncfusion.Pdf.Graphics;
using Syncfusion.Pdf.Interactive;
using Syncfusion.Pdf.Parsing;
using System;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Diagnostics;
using System.IO;
using System.Reflection;
using System.Threading.Tasks;
using System.Windows.Input;
using Xamarin.Forms;


namespace PdfTest.ViewModels
{
    public class ItemsViewModel  : Page
    {
        public ItemsViewModel()
        {
           
        }

        public Stream File { get; set; }

        public ICommand LoadCommand => new Command(() => LoadPdf());
        
        private void LoadPdf()
        {
            Assembly assembly = typeof(ItemsViewModel).GetTypeInfo().Assembly;
            Stream fileStream = assembly.GetManifestResourceStream("PdfTest.PDF.Barcode.pdf");
            byte[] buffer = new byte[fileStream.Length];
            fileStream.Read(buffer, 0, buffer.Length);
            var ldoc = new PdfLoadedDocument(buffer);

            PdfFont pdfFont = new PdfStandardFont(PdfFontFamily.Courier, 10);
            PdfBrush pdfBrush = new PdfSolidBrush(Syncfusion.Drawing.Color.Black);
            PdfTextMarkupAnnotation markupAnnotation = new PdfTextMarkupAnnotation("Markup annotation", "Markup annotation with highlight style", "Text Markup", new PointF(175, 40), pdfFont);
            markupAnnotation.TextMarkupColor = new PdfColor(Syncfusion.Drawing.Color.BlueViolet);
            markupAnnotation.TextMarkupAnnotationType = PdfTextMarkupAnnotationType.Highlight;
            ldoc.Pages[0].Annotations.Add(markupAnnotation);


            PdfFreeTextAnnotation freeText = new PdfFreeTextAnnotation(new RectangleF(50, 100, 100, 50));
            freeText.MarkupText = "Free Text with Callout";
            freeText.TextMarkupColor = new PdfColor(Syncfusion.Drawing.Color.Black);
            freeText.Font = new PdfStandardFont(PdfFontFamily.Helvetica, 7f);
            freeText.Color = new PdfColor(Syncfusion.Drawing.Color.Yellow);
            freeText.BorderColor = new PdfColor(Syncfusion.Drawing.Color.Red);
            freeText.Border = new PdfAnnotationBorder(.5f);
            freeText.LineEndingStyle = PdfLineEndingStyle.OpenArrow;
            freeText.AnnotationFlags = PdfAnnotationFlags.Default;
            freeText.Text = "Free Text";

            PointF[] points = { new PointF(100, 450), new PointF(100, 200), new PointF(100, 150) };
            freeText.CalloutLines = points;

            ldoc.Pages[0].Annotations.Add(freeText);

            using (var ms = new MemoryStream())
            {
                ldoc.Save(ms);
                File = ms;
                OnPropertyChanged(nameof(File));
            }
        }
    }
}